//
// @author Pierre Dragicevic.
//
 

 
class CountryShape {

  String name;
  float[][] xpoints, ypoints; // keep the list of points for drawing
  GeneralPath path; // maintain this Java object for hit testing and other things
  
  // Builds a new country given a string specification in the form x,y;x,y;x,y x,y;x,y ...
  // If skipVertices is set to a value greater than 0 (up to 4), will skip vertices to speed up display
  public CountryShape(String name, String pointList, int skipVertices) {
    String[] polygonStrings = split(pointList, " ");
    float[][] xpoints = new float[polygonStrings.length][];
    float[][] ypoints = new float[polygonStrings.length][];
    for (int p = 0; p < polygonStrings.length; p++) {
      String[] pointStrings = split(polygonStrings[p], ";");
      int npoints = pointStrings.length / (skipVertices + 1);
      xpoints[p] = new float[npoints];
      ypoints[p] = new float[npoints];
      for (int v = 0; v < npoints; v++) {
        String[] coordStrings = split(pointStrings[v * (skipVertices + 1)], ",");
        xpoints[p][v] = parseFloat(coordStrings[0]);
        ypoints[p][v] = parseFloat(coordStrings[1]);
      }
    }
    this.name = name;
    this.xpoints = xpoints;
    this.ypoints = ypoints;
    buildPath();
  }
  
  public CountryShape(String name, float[][] xpoints, float[][] ypoints) {
    this.name = name;
    this.xpoints = xpoints;
    this.ypoints = ypoints;
    buildPath();
  }
  
  private void buildPath() {
    path = new GeneralPath();
    for (int i = 0; i < xpoints.length; i++) {
      for (int j = 0; j < xpoints[i].length; j++) {
        if (j == 0)
          path.moveTo(xpoints[i][j], ypoints[i][j]);
        else
          path.lineTo(xpoints[i][j], ypoints[i][j]);
      }
      path.closePath();
    }
  }
 
  void draw() {
    for (int i = 0; i < xpoints.length; i++) {
      beginShape();
      for (int j = 0; j < xpoints[i].length; j++)
        vertex(xpoints[i][j], ypoints[i][j]);
      endShape(CLOSE);
    }
  }
  
  Rectangle2D getBounds() {
    return path.getBounds2D();
  }
  
  boolean contains(float x, float y) {
    return path.contains(x, y);
  }
}
