//
// Shows how to use the file countries.csv file to draw a map.
//
// @author Pierre Dragicevic
//
import java.awt.geom.*;

CountryShape[] countries; 
int w = 800, h = 400; // window size
int skipVertices = 0; // If set to a value greater than 0 (up to 5), will skip vertices to speed up display
Rectangle2D mapBounds = null; // Map bounds

void setup() {
  
  // Load the table with country names, codes and shapes
  Table table = new Table("countries.csv", "\t", null);
  
  // Build the array of country shapes based on data in the table.
  countries = new CountryShape[table.getRowCount()];
  for (int r = 0; r < table.getRowCount(); r++)
    countries[r] = new CountryShape(table.get(2, r), table.get(4, r), skipVertices);
  
  // Compute the bounding box of all countries.
  // In order to zoom in a particular region, set the variable mapBounds by hand.
  for (int r = 0; r < countries.length; r++) {
    if (mapBounds == null)
      mapBounds = countries[r].getBounds();
    else
      mapBounds = mapBounds.createUnion(countries[r].getBounds());
  }
  
  smooth();
  size(w, h);
}
 
void draw(){
  background(255);
  
  // Fit the map to the window
  scale(w / (float)mapBounds.getWidth(), -h /(float)mapBounds.getHeight());
  translate(-(float)mapBounds.getX(), (float)mapBounds.getY());
  
  // Set the same visual attributes for all countries
  fill(color(0, 0, 255, 20));
  stroke(0);
  strokeWeight(0.1);
  
  // Draw all countries
  for (int i = 0; i < countries.length; i++) {
    countries[i].draw();
  }
}


